## 社融数据（月度）

接口：sf_month

描述：获取月度社会融资数据

限量：单次最大2000条数据，可循环提取

积分：需2000积分

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| m | str | N | 月份（YYYYMM，下同），支持多个月份同时输入，逗号分隔 |
| start_m | str | N | 开始月份 |
| end_m | str | N | 结束月份 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| month | str | Y | 月度 |
| inc_month | float | Y | 社融增量当月值（亿元） |
| inc_cumval | float | Y | 社融增量累计值（亿元） |
| stk_endval | float | Y | 社融存量期末值（万亿元） |

接口调用

```python
pro = ts.pro_api()

df = pro.sf_month(start_m='201901', end_m='202307')
```

数据样例

```python
month inc_month inc_cumval stk_endval
0   202307   5282.00  220800.00     365.77
```